netapp_ontap.models.fc_port_speed API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.fc_port_speed`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FcPortSpeedSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FcPortSpeed object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `configured GET`

    The configured speed of the FC port in gigabits per second.

    Valid choices:

    - 1
    - 2
    - 4
    - 8
    - 10
    - 16
    - 32
    - auto
  `maximum GET`

    The maximum speed supported by the FC port in gigabits per second.

    Valid choices:

    - 1
    - 2
    - 4
    - 8
    - 10
    - 16
    - 32
    - auto